## Copyright (C) 2007 Sam Robson
##
## This file is part of Envisage.
##
## Envisage is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## Envisage is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Envisage; if not, write to the Free Software
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

###############################################################################
#                       BEGIN - FUNCTION - INTlevels                          #
###############################################################################

## Function to calculate the number of levels for each main effect variable 
## term and first order interaction term in the linear model

INTlevels <- function(pData) {
    ## Number of levels for each main effect term
    MElevels <- NULL
    for (i in 1:ncol(pData)) {
        if (class(pData[[i]]) == "factor" && length(levels(pData[[i]])) > 1) {
            MElevels <- c(MElevels, (length(levels(pData[[i]]))-1))
        } else MElevels <- c(MElevels, 1)
    }
    names(MElevels) <- names(pData)

    ## All possible interactions with the variables of interest
    allINT <- gsub(" ", "_", names(pData))
    allINTlevels <- MElevels
    for (i in 1:length(pData)) {		
        for (j in 1:length(pData)) {
            if (j > i && names(pData)[j] != names(pData)[i]) {
                allINT <- c(allINT, gsub(" ", "_", 
                paste(names(pData)[i], ":", names(pData)[j], sep="")))
                if (class(pData[[i]]) == "factor" && 
                    length(levels(pData[[i]])) > 1) {
                        temp1 <- length(levels(pData[[i]]))
                    } else temp1 <- 1
                if (class(pData[[j]]) == "factor" && 
                    length(levels(pData[[j]])) > 1) {
                        temp2 <- length(levels(pData[[j]]))
                    } else temp2 <- 1
                allINTlevels <- c(allINTlevels, ((temp1*temp2)-1))    
            }
        }
        rm(j)
    }
    rm(i)
    names(allINTlevels) <- allINT 

    return(allINTlevels)
}

###############################################################################
#                           END - FUNCTION - INTlevels                        #
###############################################################################   