## Copyright (C) 2007 Sam Robson
##
## This file is part of Envisage.
##
## Envisage is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## Envisage is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Envisage; if not, write to the Free Software
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

###############################################################################
#                         BEGIN - FUNCTION - corParams                        #
###############################################################################

## Flags all highly correlated variables which model the same data to reduce 
## the number of variables and interactions in the model calculation

corParams <- function(pData) 
{	
    list <- NULL
    paramCov <- matrix(ncol=ncol(pData),nrow=ncol(pData))
    rownames(paramCov) <- gsub(" ", "_", names(pData))
    colnames(paramCov) <- gsub(" ", "_", names(pData))
    switch <- 0
    flag <- ("*")
    corParams <- list()
    count <- 1
    corParamNames <- names(pData)

    ## Go through all variables to find high correlation, and flag any
    ## variables with correlation higher than 0.98   
    for (i in 1:length(corParamNames)) {
        if (switch == 1) {
            flag <- paste(flag,"*",sep="")
            switch <- 0
        }
        if (count == 1 || (count > 1 && !(i %in% corParams[[count-1]]))) {
            for (j in 1:length(corParamNames)) {
                if (i<j && abs(cor(as.numeric(pData[[i]]), 
 	            as.numeric(pData[[j]]))) >= 0.98) {
  	            if (substr(corParamNames[i],nchar(corParamNames[i]),
                        nchar(corParamNames[i])) != "*") {
                        corParamNames[i] <- paste(corParamNames[i],flag,sep=" ")
                        corParams[[count]] <- i
                    }
	            if (substr(corParamNames[j],nchar(corParamNames[j]),
                        nchar(corParamNames[j])) != "*") {
	                corParamNames[j] <- paste(corParamNames[j],flag,sep=" ")
                        corParams[[count]] <- c(corParams[[count]],j)
                    }
                    switch <- 1
                }
	    }
        }
        if (switch == 1) count <- count + 1
    }
    rm(i,j)
    return(list(corParamNames,corParams))
}

###############################################################################
#                             END - FUNCTION - corParams                      #
###############################################################################