## Copyright (C) 2007 Sam Robson
##
## This file is part of Envisage.
##
## Envisage is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## Envisage is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with envisage; if not, write to the Free Software
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

###############################################################################
#                      BEGIN - FUNCTION - dataTransform.R                     #
###############################################################################

## Extract expression values from ExpressionSet object, and ensure that data is 
## logged before analysis

dataTransform <- function(expData)
{
    ## Read in gene expression values 'd', and exclude missing values for future 
    ## calculations    
    d <- exprs(expData)
    d <- na.exclude(d)	
	
    ## Log d if it has not been logged previously (if d has been previously 
    ## logged it will be normalized around 0 instead of 1 (log1 = 0), and so we
    ## will see negative gene expression values)	   
    nonZero <- 0
    for (i in nrow(d):1) {
        for (j in 1:ncol(d)) {
            if (d[i,j] <= 0) {
       	        nonZero <- nonZero + 1
            }
        }
    }
    if (nonZero == 0) {
        d <- log2(d)
    }
    return(d)
}

###############################################################################
#                           END - FUNCTION - dataTransform.R                  #
###############################################################################