## Copyright (C) 2007 Sam Robson
##
## This file is part of Envisage.
##
## Envisage is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## Envisage is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Envisage; if not, write to the Free Software
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

###############################################################################
#                    BEGIN - FUNCTION - modelEntry                            #
###############################################################################

## Allows users to specify a minimum model for the model selection process

modelEntry <- function(pData, Mentry, useParams, labParams, MEorINT, glm.formula) 
{
    ###########################################################################
    #                                 1 - GUI                                 #
    ###########################################################################

    if (!missing(Mentry)) {

    ## Original variable names before removal of labelling, etc.
    orgParamNames <- names(pData)
    nOrgParam <- length(orgParamNames)

    ## Create starting model by pulling out the labels from the model
    ## that the user has supplied
    Minput <- tclvalue(tkget(Mentry))
    if (nchar(Minput) == 0) {
        startingModel <- "x ~ 1"
        intPos <- NULL
    } else if (nchar(Minput) != 0) {
        ## Find the positions of the "+" characters
        plusPos <- NULL
        for (i in 1:nchar(Minput)) {
            if (substr(Minput, i, i) == "+") {
                plusPos <- c(plusPos, i)
            }
        }
        rm(i)
 
        ## Seperate out the terms
        MtermsP <- list()
        if (length(plusPos) != 0) {
            count <- 1
            for (i in 1:length(plusPos)) {
                MtermsP[[i]] <- substr(Minput, count, (plusPos[i]-1))
                count <- plusPos[i]+1
            }
            MtermsP[[length(plusPos)+1]] <- substr(Minput, 
                (plusPos[length(plusPos)]+1), nchar(Minput))
        } else if (length(plusPos) == 0) {
            MtermsP[[1]] <- Minput
        }

        ## Find the interaction terms
        intPos <- NULL
        for (i in 1:length(MtermsP)) {
            for (j in 1:nchar(MtermsP[[i]])) {
                if (substr(MtermsP[[i]], j, j) == ":") {
                    intPos <- c(intPos, i)
                } 
            }
        }

        ## Pull out the values for the terms in the main model
        Mlabels <- list()
        for (i in 1:length(MtermsP)) {
            ## If not an interaction term
            if (!i %in% intPos) {
                for (j in 1:nchar(MtermsP[[i]])) {
                    if ((substr(MtermsP[[i]], j, j)) %in% 0:9) {
                        Mlabels[[i]] <- as.numeric(substr(MtermsP[[i]], j, j))
                        if ((substr(MtermsP[[i]], j, j+1)) %in% 0:99) {
                            Mlabels[[i]] <- as.numeric(substr(MtermsP[[i]], j, 
                                j+1))
                            break
                        } else break
                    }
                }
            ## If the term is an interaction
            } else if (i %in% intPos) {
                colPos <- NULL
                for (j in 1:nchar(MtermsP[[i]])) {
                    if (substr(MtermsP[[i]], j, j) == ":") {
                        colPos <- j
                    } 
                }
    
                Mlabels[[i]] <- vector(length=2)
                for (j in 1:colPos) {
                    if ((substr(MtermsP[[i]], j, j)) %in% 0:9) {
                        Mlabels[[i]][1] <- as.numeric(substr(MtermsP[[i]], j, j))
                        if ((substr(MtermsP[[i]], j, j+1)) %in% 0:99) {
                            Mlabels[[i]][1] <- as.numeric(substr(MtermsP[[i]], j, 
                                j+1))
                            break
                        } else break
                    }
                }
                for (j in colPos:nchar(MtermsP[[i]])) {
                    if ((substr(MtermsP[[i]], j, j)) %in% 0:9) {
                        Mlabels[[i]][2] <- as.numeric(substr(MtermsP[[i]], j, j))
                        if ((substr(MtermsP[[i]], j, j+1)) %in% 0:99) {
                            Mlabels[[i]][2] <- as.numeric(substr(MtermsP[[i]], j, 
                                j+1))
                            break
                        } else break
                    }
                } 
            }                     
        }
   
        ## Convert the numbers into variable names
        Mnames <- Mlabels
        for (i in 1:length(Mlabels)) {
            for (j in 1:length(Mlabels[[i]])) {
                if (Mlabels[[i]][j] > nOrgParam) {
                    tkmessageBox(title="Model terms out of bounds", 
                        message=paste("Warning: Please ensure that the terms ",
                        "specificed in\nthe starting model are in the range p1 ",
                        "to p",nOrgParam, ".", sep=""), type="ok", 
                        icon="warning")
    
                    ## Stop if a problem
                    stop()      
                } else Mnames[[i]][j] <- gsub(" ", "_", 
                    orgParamNames[Mlabels[[i]][j]])
            }
        }
  
        ## Check that the variables to be used in the model have been selected
        ## by the user
        for (i in 1:length(Mnames)) {
            for (j in 1:length(Mnames[[i]])) {
                if (!(gsub("_", " ", Mnames[[i]][j]) %in% useParams)) {
                    if (gsub("_", " ", Mnames[[i]][j]) %in% labParams) {
                        tkmessageBox(title=paste("Selected labelling variables",
                            " as model terms", sep=""), message=paste("You have",
                            " selected variable '", gsub("_", " ", 
                            Mnames[[i]][j]) ,"' as a variable for the ",
                            "starting\nmodel, which has been flagged as a ",
                            "labelling variable. It is\nrecommended that you ",
                            "do not use this variable in your model\nto ",
                            "prevent overfitting.", sep=""), type="ok", 
                            icon="warning")
 
                        ## Stop if a problem
                        stop()
                    } else if (!(gsub("_", " ", 
                        Mnames[[i]][j]) %in% labParams)) {
                        tkmessageBox(title="Model terms not selected", 
                            message=paste("You have selected variable '", 
                            gsub("_", " ", Mnames[[i]][j]) ,"' as a variable ",
                            "for\nthe starting model. Please ensure that you ",
                            "have also ticked\nthe 'Choose Model Variable' box",
                            " for this variable.", sep=""), type="ok", 
                            icon="warning")
  
                        ## Stop if a problem
                        stop()
                    }
                } else if (gsub("_", " ", Mnames[[i]][j]) %in% useParams) {
                    ## Create starting model from the selected terms
                    startingModel <- "x ~ "
                    for (i in 1:length(Mlabels)) {
                        ## For main effect terms
                        if (length(Mlabels[[i]]) == 1) {
                            startingModel <- paste(startingModel, Mnames[[i]],
                                " + ", sep="")
                        } else if (length(Mlabels[[i]]) == 2) {
                            startingModel <- paste(startingModel, Mnames[[i]][1], 
                                ":", Mnames[[i]][2], " + ", sep="")
                        }
                    }
                    startingModel <- substr(startingModel, 1, 
                        nchar(startingModel)-3)
                }
            }
        }               
    }
    terms <- NULL
    }


    ###########################################################################
    #                            1 - Command line                             #
    ###########################################################################

    if(!missing(glm.formula)) {
    
    ## Find tilda character
    tilPos <- NULL
    for (i in 1:nchar(glm.formula)) {
        if (substr(glm.formula, i, i) == "~") {
            tilPos <- c(tilPos, i)
        }
    } 

    ## Start of terms 
    for (i in (tilPos+1):nchar(glm.formula)) {
        if (substr(glm.formula, i, i) != " ") {
            termStart <- i
            break
        }
    } 
    
    ## Find plus characters
    plusPos <- NULL
    for (i in 1:nchar(glm.formula)) {
        if (substr(glm.formula, i, i) == "+") {
            plusPos <- c(plusPos, i)
        }
    }
    plusPos <- c(plusPos, (nchar(glm.formula)+2))
  
    ## Find interactions
    intPos <- NULL
    for (i in 1:nchar(glm.formula)) {
        if (substr(glm.formula, i, i) == ":") {
            intPos <- c(intPos, i)
        }
    }  

    ## Find model terms
    if (length(plusPos) > 0) {
        terms <- NULL
        count <- termStart
        for (i in 1:length(plusPos)) {
            terms <- c(terms, substr(glm.formula, count, (plusPos[i]-2)))
            count <- plusPos[i]+2
        }
    }

    ## Create starting glm.formula
    startingModel <- "x ~"
    for (i in 1:length(terms)) {
        temp <- ifelse(substr(terms[i],1,1) != "'", terms[i],
            paste("'", terms[i], sep=""))
        temp <- ifelse(substr(temp, nchar(temp), nchar(temp)) != "'", 
            temp, paste(temp, "'", sep=""))
        temp <- gsub(" ", "_", temp)
        startingModel <- paste(startingModel, temp, "+")
    }
    startingModel <- substr(startingModel, 1, (nchar(startingModel)-2))
    startingModel <- as.formula(startingModel)  

    }

    out <- list(startingModel=startingModel, intPos=intPos)
    return(out)
}

###############################################################################
#                         END - FUNCTION - modelEntry                         #
###############################################################################