\name{alias.glmNA}
\alias{alias.glmNA}
\title{Find Aliases (Dependencies) in a Model}
\description{Find aliases (linearly dependent terms) in a linear model
  specified by a formula. This extends the S3 method
  \code{\link[stats]{alias}} to objects of class
  \code{\link[Envisage:glmNA-class]{glmNA}} for package \pkg{Envisage}.
}
\usage{
  \method{alias}{glmNA}(object, ...) 
}
\arguments{
  \item{object}{A fitted model object of class
    \code{\link[Envisage:glmNA-class]{glmNA}}.}
  \item{...}{Further arguments passed to or from other methods.}
}

\details{
  The \pkg{Envisage} package contains methods allowing the use of  
  linear models (LMs) for analysing significantly changing genes in  
  experiments with a variety of sources of variation, be they
  experimentally controlled variables such as drug treatment or time, or
  non-controlled sources of confounding variation such as phenotypic or
  environmental differences. This allows all sources of variation to be
  considered when analysing for significant differential expression,
  ensuring resulting genes are biologically relevent to the experimental
  question. 
    
  The function \code{\link[Envisage]{alias.glmNA}} extends the method
  \code{\link[stats]{alias}} to the S4 class
  \code{\link[Envisage:glmNA-class]{glmNA}} for package
  \pkg{Envisage}. This is an extension of classes \code{glm} and
  \code{lm} and deals appropriately with genes that produce NA calls in
  the modelling procedure. This allows use of the function
  \code{\link[car]{Anova}} for calculating significance for each gene. 

  \code{\link[Envisage]{alias.glmNA}} is an internal function and is not
  designed to be accessed by users. 
}
\value{
  A list (of class "listof") containing components:

  \item{Model}{Description of the model; usually the formula.}
  \item{Complete}{A matrix with columns corresponding to effects that
    are linearly dependent on the rows.}
  \item{Partial}{The correlations of the estimable effects, with a zero
    diagonal. An object of class "mtable" which has its own print
    method.}
}
\references{
  Robson, S. C., Hunter, E., Bird, H., Turner, H. (2008) 
  \emph{Envisage: model-based significance analysis of microarray gene
    expression data}, manuscript in preparation.
}
\author{Sam Robson \email{S.C.Robson@warwick.ac.uk}}
\seealso{
  \code{\link[stats]{coef}}, \code{\link[Envisage:class.glmNA]{glmNA}. For the main \pkg{Envisage} method, see
  \code{\link[Envisage]{envisage}}.}
} 
\keyword{models}
