\name{corParams}
\alias{corParams}
\title{Flag highly correlated parameters}
\description{Flags all highly correlated variables which model the same
  data to reduce the number of variables and interactions in the model
  calculation.} 
\usage{
  corParams(pData) 
}
\arguments{
  \item{pData}{An object of class
    \code{\link[Biobase:class.phenoData]{phenoData}} containing the
      phenotypic information for the experiment.}
}

\details{
  The \pkg{Envisage} package contains methods allowing the use of 
  linear models (LMs) for analysing significantly changing genes in 
  experiments with a variety of sources of variation, be they
  experimentally controlled variables such as drug treatment or time, or
  non-controlled sources of confounding variation such as phenotypic or
  environmental differences. This allows all sources of variation to be
  considered when analysing for significant differential expression,
  ensuring resulting genes are biologically relevent to the experimental
  question. 
    
  The function \code{\link[Envisage]{corParams}} identifies variables
  within the study design that are highly correlated and flags
  them up for the user. These may represent different representations of
  the same data and will affect model fitting, so should be removed from
  the data set. Variables found to be highly correlated are suffixed
  with the flags '*', '**', '***' etc.
  
  \code{\link[Envisage]{corParams}} is an internal function and is not
  designed to be accessed by users. 
}
\value{
  A list is returned containing the following slots:

  \item{corParamNames}{A character vector of the names of the parameters
    found to have very high correlation, suffixed with flags '*', '**',
    '***' etc.} 
  \item{corParams}{A list containing the indices for variables found to
    be highly correlated with one another.}
}
\references{
  Robson, S. C., Hunter, E., Bird, H., Turner, H. (2008) 
  \emph{Envisage: model-based significance analysis of microarray gene
  expression data}, manuscript in preparation
}
\author{Sam Robson \email{S.C.Robson@warwick.ac.uk}}
\seealso{For the main \pkg{Envisage} method, see
  \code{\link[Envisage]{envisage}}.} 
\keyword{models}
