\name{dataTransform}
\alias{dataTransform}
\title{Gene expression data formatting for Envisage}
\description{Ensures that the gene expression data from the
  \code{\link[Biobase:class.ExpressionSet]{ExpressionSet}} object is in
  the correct format for package \pkg{Envisage}.}
\usage{
  dataTransform(expData)  
}
\arguments{
  \item{expData}{Object of class
    \code{\link[Biobase:class.ExpressionSet]{ExpressionSet}} containing
    gene expression data.}
}

\details{
  The \pkg{Envisage} package contains methods allowing the use of 
  linear models (LMs) for analysing significantly changing genes in 
  experiments with a variety of sources of variation, be they
  experimentally controlled variables such as drug treatment or time, or
  non-controlled sources of confounding variation such as phenotypic or
  environmental differences. This allows all sources of variation to be
  considered when analysing for significant differential expression,
  ensuring resulting genes are biologically relevent to the experimental
  question. 
    
  The function \code{\link[Envisage]{dataTransform}} is an internal
  function that ensures that the gene expression data (in the
  form of an object of class
  \code{\link[Biobase:class.ExpressionSet]{ExpressionSet}}) is in the
  correct format for future processing. In particular, this function
  ensures that data is in a logged format.

  \code{\link[Envisage]{dataTransform}} is an internal function and is
  not designed to be accessed by users.   
}
\value{
  Returns a matrix of processed expression values (this may be very large).
}
\references{
  Robson, S. C., Hunter, E., Bird, H., Turner, H. (2008) 
  \emph{Envisage: model-based significance analysis of microarray gene
  expression data}, manuscript in preparation
}
\author{Sam Robson \email{S.C.Robson@warwick.ac.uk}}
\seealso{For the main \pkg{Envisage} method, see
  \code{\link[Envisage]{envisage}}.}
\keyword{models}
