\name{labelParams}
\alias{labelParams}
\title{Remove labelling variables}
\description{This function removes any categorical variables which have
  the same number of levels as there are samples (labelling variables).}
\usage{
  labelParams(pData) 
}
\arguments{
  \item{pData}{An object of class
    \code{\link[Biobase:class.phenoData]{phenoData}} containing the
      phenotypic information for the experiment.}
}

\details{
  The \pkg{Envisage} package contains methods allowing the use of linear
  models (LMs) for analysing significantly changing genes in experiments
  with a variety of sources of variation, be they experimentally
  controlled variables such as drug treatment or time, or non-controlled  
  sources of confounding variation such as phenotypic or environmental 
  differences. This allows all sources of variation to be considered when 
  analysing for significant differential expression, ensuring resulting
  genes are biologically relevent to the experimental question.
    
  The function \code{\link[Envisage]{labelParams}} ensures that any
  categorical variables included by the user for model fitting that have
  the same number of factor levels as there are samples are removed
  prior to fitting the model. Such labelling variables contain a unique
  value for each sample, and will this result in a perfect fit for the
  data. 

  \code{\link[Envisage]{labelParams}} is an internal function and is not
  designed to be accessed by users.   
}
\value{
  A vector is returned containing the indices of the labelling
  parameters for the \code{\link[Biobase:class.phenoData]{phenoData}}
  object \code{pData}.
}
\references{
  Robson, S. C., Hunter, E., Bird, H., Turner, H. (2008) 
  \emph{Envisage: model-based significance analysis of microarray gene
  expression data}, manuscript in preparation
}
\author{Sam Robson \email{S.C.Robson@warwick.ac.uk}}
\seealso{For the main \pkg{Envisage} method, see \code{\link[Envisage]{envisage}}.}
\keyword{models}
