\name{modelEntry}
\alias{modelEntry}
\title{Specify a minimum model for step-wise model fitting}
\description{This function allows specification of a minimum model for
  the step-wise model fitting procedure in the \pkg{Envisage} GUI. This
  can 'force' terms of interest to always be considered in the model for
  each gene.}
\usage{
  modelEntry(pData, Mentry, useParams, labParams, MEorINT, glm.formula) 
}
\arguments{
  \item{pData}{An object of class
    \code{\link[Biobase:class.phenoData]{phenoData}} containing the
      phenotypic information for the experiment.}
  \item{Mentry}{Object of class \code{tkentry} containing the model
    entry field from the \pkg{Envisage} GUI. This is used if the
    starting model is specified in the GUI.}
  \item{useParams}{Character vector containing the variable names to be
    used in the model fitting procedure.}
  \item{labParams}{Output from function
    \code{\link[Envisage]{labelParams}}, containing the indices of the
    labelling parameters for the
    \code{\link[Biobase:class.phenoData]{phenoData}} object \code{pData}.}
  \item{MEorINT}{Character string indicating whether to look at main
    effect terms only ('\code{ME}') or main effect and interaction terms
    ('\code{INT}').}
  \item{glm.formula}{Object of class \code{formula} containing the
    minimal model for the step-wise model fitting procedure.}
}

\details{
  The \pkg{Envisage} package contains methods allowing the use of 
  linear models (LMs) for analysing significantly changing genes in 
  experiments with a variety of sources of variation, be they
  experimentally controlled variables such as drug treatment or time, or
  non-controlled sources of confounding variation such as phenotypic or
  environmental differences. This allows all sources of variation to be
  considered when analysing for significant differential expression,
  ensuring resulting genes are biologically relevent to the experimental
  question. 
    
  The function \code{\link[Envisage]{modelEntry}} is used to set up the
  maximum and minimum models for the \pkg{Envisage} step-wise model
  fitting procedure. This can be done in one of two ways. If using the
  command line interface to \code{\link[Envisage]{envisage}}, the model
  can be explicitly stated in the command line in the form 
  'X ~ var1 + var2:var3 + etc.'. However, if
  using the GUI (\code{widget=TRUE}), users can specify the model in
  terms of the variable labels (of the form \code{p1}, \code{p2},
  \code{p3}, etc. (e.g. \code{p1+p3+p5:p6}). This function processes
  these values to give the minimum model for the analysis.

  \code{\link[Envisage]{modelEntry}} is an internal function and is not
  designed to be accessed by users.   
}
\value{
  A list is returned with the followig slots:

  \item{startingModel}{An object of class \code{formula} giving the
    minimum model for the the step-wise model fitting procedure.}
  \item{intPos}{An internal object used to identify the location of
    interaction terms within the minimum model.}
}
\references{
  Robson, S. C., Hunter, E., Bird, H., Turner, H. (2008) 
  \emph{Envisage: model-based significance analysis of microarray gene
  expression data}, manuscript in preparation
}
\author{Sam Robson \email{S.C.Robson@warwick.ac.uk}}
\seealso{For the main \pkg{Envisage} method, see
  \code{\link[Envisage]{envisage}}.} 
\keyword{models}
