\name{mulTestCor}
\alias{mulTestCor}
\title{Multiple testing corrections for package Envisage}
\description{This function corrects the p-values obtained from package
  \pkg{Envisage} to account for problems with multiple testing. These
  corrected p-values give a measure of the significance of model terms
  on the effects on gene expression changes for individual genes.}
\usage{
  mulTestCor(pValues, MTC, pData, exprData, param4INT) 
}
\arguments{
  \item{pValues}{An object of class \code{data.frame} containing the
    p-values from the Type II sum of squares analysis for each model
    term for each gene.}
  \item{MTC}{A character string that defines which multiple testing 
    correction method to use (if any).  Available methods are
    \code{None}, \code{BH}, \code{BY}, \code{Bonferroni}, \code{Holm},
    \code{Hochberg}, \code{SidakSS}, \code{SidakSD}. More information on
    these can be found in the package vignette. \code{BH} is selected by
    default.} 
  \item{pData}{An object of class
    \code{\link[Biobase:class.phenoData]{phenoData}} containing the
      phenotypic information for the experiment.}
  \item{exprData}{A matrix of expression values for each gene for each
    sample. Usually calculated using \code{\link[Biobase]{exprs}} on an
    object of class
    \code{\link[Biobase:class.ExpressionSet]{ExpressionSet}}.}
  \item{param4INT}{Character vector of variables for which interaction
    terms should be calculated.}
}

\details{
  The \pkg{Envisage} package contains methods allowing the use of 
  linear models (LMs) for analysing significantly changing genes in 
  experiments with a variety of sources of variation, be they
  experimentally controlled variables such as drug treatment or time, or
  non-controlled sources of confounding variation such as phenotypic or
  environmental differences. This allows all sources of variation to be
  considered when analysing for significant differential expression,
  ensuring resulting genes are biologically relevent to the experimental
  question. 
    
  Due to the large number of genes analysed, gene expression analyses
  can suffer from problems due to multiple hypothesis testing. The
  function \code{\link[Envisage]{mulTestCor}} performs the selected
  multiple testing correction on the p-values indicating significance of
  each model term for each gene in the analysis. 

  \code{\link[Envisage]{mulTestCor}} is an internal function and is not
    designed to be accessed by users.   
}
\value{
  An object of class \code{data.frame} is returned containing the
  adjusted p-values for each model term for each gene.
}
\references{
  Robson, S. C., Hunter, E., Bird, H., Turner, H. (2008) 
  \emph{Envisage: model-based significance analysis of microarray gene
  expression data}, manuscript in preparation
}
\author{Sam Robson \email{S.C.Robson@warwick.ac.uk}}
\seealso{For the main \pkg{Envisage} method, see
  \code{\link[Envisage]{envisage}}.} 
\keyword{models}
