## Copyright (C) 2007 Sam Robson
##
## This file is part of Envisage.
##
## Envisage is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## Envisage is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Envisage; if not, write to the Free Software
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

###############################################################################
#                     BEGIN - FUNCTION - mulTestCor                           #
###############################################################################

## Use specified multiple testing correction to correct p values for multiple
## hypothesis testing

mulTestCor <- function(pValues, MTC, pData, exprData, param4INT) 
{
    ## Create names of all possible main effect and first order 
    ## interaction terms
    paramInt <- gsub(" ", "_", names(pData))
    if (length(param4INT) != 0) {
        for (i in 1:length(param4INT)) {
            for (j in 1:length(param4INT)) {
                 if (param4INT[j] != param4INT[i]) {
                 paramInt <- c(paramInt, gsub(" ", "_", paste(param4INT[i], 
                     ":", param4INT[j], sep="")))
                 }
            }
        }
        rm(i, j)
    }
    nInt <- length(paramInt)

    ## Create matrix in which to store all p-value results for MTC
    allPVal <- as.data.frame(matrix(data=NA, nrow=nrow(exprData), ncol=nInt,
        dimnames=list(rownames(exprData), paramInt)))
    for (i in 1:nrow(exprData)) {
        if (!is.na(pValues[[i]])[1]) {
            for (j in 1:length(pValues[[i]])) {
                allPVal[[names(pValues[[i]])[j]]][i] <- pValues[[i]][j]
            }
        }
    }
    rm(i,j)
	
    ## MTC across all genes	
    if (MTC != "None") {
        adjp <- as.data.frame(matrix(data=NA, nrow=nrow(exprData), ncol=nInt,
            dimnames=list(rownames(exprData), paramInt)))
        for (i in 1:nInt) {
            rawp <- allPVal[[i]]
            names(rawp) <- rownames(exprData)
            temp <- mt.rawp2adjp(rawp, proc=MTC)
            adjp[temp$index, i] <- temp$adjp[, 2]
        }
        rm(i)
    } else adjp <- allPVal
    return(adjp)
}

###############################################################################
#                           END - FUNCTION - mulTestCor                       #
###############################################################################